pub struct CChangeDifficulty {
pub difficulty: Difficulty,
pub locked: bool,
}Expand description
Clientbound packet that informs the client about the current world difficulty.
Sent during login, respawn, and whenever the difficulty changes.
Fields
difficulty: DifficultyThe difficulty level.
locked: boolWhether the difficulty is locked (prevents players from changing it).