CPlayerInfoUpdate

Struct CPlayerInfoUpdate 

pub struct CPlayerInfoUpdate {
    pub actions: u8,
    pub entries: Vec<PlayerInfoEntry>,
}

Fields

actions: u8entries: Vec<PlayerInfoEntry>

Implementations

Source

impl CPlayerInfoUpdate

pub fn create_player_initializing( uuid: Uuid, name: String, properties: Vec<GameProfileProperty>, game_mode: i32, latency: i32, display_name: Option<TextComponent>, show_hat: bool, ) -> Self

Creates a full player initializing packet with all information. This is sent when a player joins to add them to the tab list. Matches vanilla’s ClientboundPlayerInfoUpdatePacket.createPlayerInitializing()

pub fn update_chat_session( uuid: Uuid, chat_session: ProtocolRemoteChatSessionData, ) -> Self

Creates a packet to update a player’s chat session.

pub fn update_latency(entries: Vec<(Uuid, i32)>) -> Self

Creates a packet to update latency for multiple players. This is sent periodically (every 600 ticks) to update ping display.

pub fn update_game_mode(uuid: Uuid, game_mode: i32) -> Self

Creates a packet to update a player’s game mode.

pub fn update_listed(uuid: Uuid, listed: bool) -> Self

Creates a packet to update a player’s listed status (show/hide in tab list).

pub fn update_display_name( uuid: Uuid, display_name: Option<TextComponent>, ) -> Self

Creates a packet to update a player’s display name.

pub fn update_hat(uuid: Uuid, show_hat: bool) -> Self

Creates a packet to update a player’s hat visibility.

pub fn update_list_order(uuid: Uuid, list_order: i32) -> Self

Creates a packet to update a player’s list order (sort position in tab list).