CPlayerPosition

Struct CPlayerPosition 

pub struct CPlayerPosition {
    pub teleport_id: i32,
    pub pos: DVec3,
    pub vel: DVec3,
    pub yaw: f32,
    pub pitch: f32,
    pub relatives: RelativeMovement,
}
Sent to teleport a player to a new position.

The client must acknowledge this packet by sending SAcceptTeleportation with the same teleport ID. Until acknowledged, the server will reject position updates from the client.

Fields

teleport_id: i32

Unique teleport ID that must be echoed back by the client.

pos: DVec3

Target position

vel: DVec3

Target velocity (delta movement)

yaw: f32

Target yaw (Y rotation)

pitch: f32

Target pitch (X rotation)

relatives: RelativeMovement

Relative movement flags

Implementations

Source

impl CPlayerPosition

pub const fn new( teleport_id: i32, pos: DVec3, vel: DVec3, yaw: f32, pitch: f32, relatives: RelativeMovement, ) -> Self

Creates a teleport packet with explicit relative flags.

pub const fn absolute( teleport_id: i32, pos: DVec3, yaw: f32, pitch: f32, ) -> Self

Creates a new absolute teleport packet.

pub const fn absolute_with_velocity( teleport_id: i32, pos: DVec3, vel: DVec3, yaw: f32, pitch: f32, ) -> Self

Creates a new absolute teleport packet with explicit delta movement.

pub const fn with_relative_rotation(teleport_id: i32, pos: DVec3) -> Self

Creates a teleport packet with relative rotation (keeps current rotation).