pub struct CSetEquipment {
pub entity_id: i32,
pub slots: Vec<EquipmentSlotItem>,
}Expand description
Updates one or more equipment slots for an entity.
Fields
entity_id: i32Entity id whose equipment changed.
slots: Vec<EquipmentSlotItem>Slot updates. Vanilla requires at least one entry when this packet is sent.
Implementations
Sourceimpl CSetEquipment
impl CSetEquipment
Sourcepub const fn new(entity_id: i32, slots: Vec<EquipmentSlotItem>) -> Self
pub const fn new(entity_id: i32, slots: Vec<EquipmentSlotItem>) -> Self
Creates a new equipment update packet.