CTakeItemEntity

Struct CTakeItemEntity 

pub struct CTakeItemEntity {
    pub item_id: i32,
    pub player_id: i32,
    pub amount: i32,
}
Sent when an entity picks up an item (item, experience orb, or arrow).

Triggers the pickup animation on the client where the item entity flies towards the collector entity before disappearing.

Corresponds to vanilla’s ClientboundTakeItemEntityPacket.

Fields

item_id: i32

The entity ID of the item being picked up.

player_id: i32

The entity ID of the collector (player or other entity).

amount: i32

The number of items picked up (for animation/sound).

Implementations

Source

impl CTakeItemEntity

pub const fn new(item_id: i32, player_id: i32, amount: i32) -> Self

Creates a new take item entity packet.