pub struct SClientCommand {
pub action: ClientCommandAction,
}Expand description
Sent by the client when it wants to perform an action such as respawning after death.
When the player dies and sees the death screen, clicking “Respawn” sends this
packet with action = PerformRespawn.
Fields
action: ClientCommandActionThe action the client wants to perform.